From 1832d5ff905b16435efa64e458e2ca2f656f0ab5 Mon Sep 17 00:00:00 2001
From: Oliver Freyermuth <o.freyermuth@googlemail.com>
Date: Sun, 19 Dec 2021 16:30:27 +0100
Subject: [PATCH] configure: Add musl compatibility (external argp).

---
 configure.ac | 20 ++++++++++++++++++++
 1 file changed, 20 insertions(+)

diff --git a/configure.ac b/configure.ac
index 687d4d4..9f708cf 100644
--- a/configure.ac
+++ b/configure.ac
@@ -109,6 +109,26 @@ AC_CHECK_LIB([rt], [shm_open], [LIBRT=-lrt], [
 ])
 AC_SUBST([LIBRT])
 
+# argp_parse, needed externally from libargp / argp_standalone e.g. with musl.
+# First, check if available in used libc out of the box.
+AC_LINK_IFELSE(
+  [AC_LANG_PROGRAM(
+    [#include <argp.h>],
+    [int argc=1; char **argv=NULL; argp_parse(0,argc,argv,0,0,0); return 0;]
+  )],
+  [libc_provides_argp="true"],
+  [libc_provides_argp="false"]
+)
+# If libc doesn't provide argp, test for libargp
+if test "$libc_provides_argp" = "false" ; then
+  AC_MSG_WARN("libc does not provide argp")
+  AC_CHECK_LIB([argp], [argp_parse], [have_largp="true"], [have_largp="false"])
+  if test "$have_largp" = "false"; then
+    AC_MSG_ERROR([*** argp functions not found - install libargp or argp_standalone])
+  else
+    CH_RUN_LIBS="-largp $CH_RUN_LIBS"
+  fi
+fi
 
 ## Options
 
-- 
2.32.0

